# User Manual

???+ note

    This manual is under development.

!!! info

    If you opened this documentation from the sonarcal program you will be reading the offline version. The online version is available [here](https://aqualyd-limited.github.io/sonarCal/).

## Introduction

This is the user documentation for the sonarcal program.

It supports viewing and deriving beam gain calibrations from omni-directional sonars:

|Manufacturer|Model|Supported file formats|
|---|---|---|
|Furuno|XXX|sonar-netCDF4|
|Kongsberg Discovery|SU90|sonar-netCDF4|
|Kongsberg Discovery|CS90|raw, sonar-netCDF4|
|Kongsberg Discovery|SN90|raw, sonar-netCDF4|

Other sonars that output sonar-netCDF4 files may also work, but there can often be small adjustments needed for full support.

The development of the current form of this program was supported by [AZTI](https://www.azti.es/en/). Earlier versions were developed while the author was employed at the Norwegian [Institute of Marine Research](https://www.hi.no).

## How to use

![Main screen](assets/screenshot.png){ align=right }
/// caption
The main operation screen.
///

![Beam ping amplitudes](assets/Beam_example.png){ align=right }
/// caption
The seconday display of ping amplitudes.
///

## Configuration

some text

## Export of data

some text
